@@ -86,13 +86,13 @@ ProjectClip::ProjectClip(const QDomElement& description, QIcon thumb, ProjectFol
             m_thumbnail = KoIconUtils::themedIcon(QStringLiteral("audio-x-generic"));
         }
     }
-    m_temporaryUrl = QUrl::fromLocalFile(getXmlProperty(description, QStringLiteral("resource")));
+    m_temporaryUrl = getXmlProperty(description, QStringLiteral("resource"));
     QString clipName = getXmlProperty(description, QStringLiteral("kdenlive:clipname"));
     if (!clipName.isEmpty()) {
         m_name = clipName;
     }
-    else if (m_temporaryUrl.isValid()) {
-        m_name = m_temporaryUrl.fileName();
+    else if (!m_temporaryUrl.isEmpty()) {
+        m_name = QFileInfo(m_temporaryUrl).fileName();
     }
     else m_name = i18n("Untitled");
     connect(this, &ProjectClip::updateJobStatus, this, &ProjectClip::setJobStatus);
@@ -123,7 +123,7 @@ void ProjectClip::abortAudioThumbs()
 
 QString ProjectClip::getToolTip() const
 {
-    return url().toLocalFile();
+    return url();
 }
 
 QString ProjectClip::getXmlProperty(const QDomElement &producer, const QString &propertyName, const QString &defaultValue)
@@ -238,11 +238,11 @@ ProjectClip* ProjectClip::clipAt(int ix)
 
 bool ProjectClip::hasUrl() const
 {
-    if (m_controller && (m_type != Color) && (m_type != Unknown)) return (m_controller->clipUrl().isValid());
+    if (m_controller && (m_type != Color) && (m_type != Unknown)) return (!m_controller->clipUrl().isEmpty());
     return false;
 }
 
-QUrl ProjectClip::url() const
+const QString ProjectClip::url() const
 {
     if (m_controller) return m_controller->clipUrl();
     return m_temporaryUrl;
@@ -297,7 +297,7 @@ QDomElement ProjectClip::toXml(QDomDocument& document, bool includeMeta)
         // We only have very basic infos, like id and url, pass them
         QDomElement prod = document.createElement(QStringLiteral("producer"));
         prod.setAttribute(QStringLiteral("id"), m_id);
-        EffectsList::setProperty(prod, QStringLiteral("resource"), m_temporaryUrl.path());
+        EffectsList::setProperty(prod, QStringLiteral("resource"), m_temporaryUrl);
         if (m_type != Unknown) {
             prod.setAttribute(QStringLiteral("type"), (int) m_type);
         }
@@ -358,13 +358,14 @@ bool ProjectClip::setProducer(ClipController *controller, bool replaceProducer)
             }
         }
     }
-    if (m_controller)
+    if (m_controller) {
         m_duration = m_controller->getStringDuration();
+    }
     m_clipStatus = StatusReady;
     if (!hasProxy()) bin()->emitRefreshPanel(m_id);
     bin()->emitItemUpdated(this);
     // Make sure we have a hash for this clip
-    hash();
+    getFileHash();
     createAudioThumbs();
     return isNewProducer;
 }
@@ -535,7 +536,7 @@ const QString ProjectClip::getFileHash() const
     QByteArray fileHash;
     switch (m_type) {
       case SlideShow:
-          fileData = m_controller ? m_controller->clipUrl().toLocalFile().toUtf8() : m_temporaryUrl.toLocalFile().toUtf8();
+          fileData = m_controller ? m_controller->clipUrl().toUtf8() : m_temporaryUrl.toUtf8();
           fileHash = QCryptographicHash::hash(fileData, QCryptographicHash::Md5);
           break;
       case Text:
@@ -551,7 +552,7 @@ const QString ProjectClip::getFileHash() const
           fileHash = QCryptographicHash::hash(fileData, QCryptographicHash::Md5);
           break;
       default:
-          QFile file(m_controller ? m_controller->clipUrl().toLocalFile() : m_temporaryUrl.toLocalFile());
+          QFile file(m_controller ? m_controller->clipUrl() : m_temporaryUrl);
           if (file.open(QIODevice::ReadOnly)) { // write size and hash only if resource points to a file
               /*
                * 1 MB = 1 second per 450 files (or faster)
@@ -633,7 +634,7 @@ void ProjectClip::setProperties(QMap <QString, QString> properties, bool refresh
         }
         else {
             // A proxy was requested, make sure to keep original url
-            setProducerProperty(QStringLiteral("kdenlive:originalurl"), url().toLocalFile());
+            setProducerProperty(QStringLiteral("kdenlive:originalurl"), url());
             bin()->startJob(m_id, AbstractClipJob::PROXYJOB);
         }
     }
@@ -858,7 +859,7 @@ void ProjectClip::doExtractIntra()
         pos = m_intraThumbs.takeFirst();
         m_intraThumbMutex.unlock();
         if (pos >= max) pos = max - 1;
-        const QString path = url().path() + '_' + QString::number(pos);
+        const QString path = url() + '_' + QString::number(pos);
         QImage img = bin()->findCachedPixmap(path);
         if (!img.isNull()) {
             // Cache already contains image
@@ -909,7 +910,7 @@ void ProjectClip::doExtractImage()
             continue;
         }
         if (pos >= max) pos = max - 1;
-        const QString path = url().path() + '_' + QString::number(pos);
+        const QString path = url() + '_' + QString::number(pos);
         QImage img = bin()->findCachedPixmap(path);
         if (!img.isNull()) {
             emit thumbReady(pos, img);
@@ -1013,10 +1014,14 @@ void ProjectClip::slotCreateAudioThumbs()
             channelTmpfile->close();
             channelFiles << channelTmpfile;
         }
-        args << QStringLiteral("-i") << QUrl::fromLocalFile(prod->get("resource")).path();
+        args << QStringLiteral("-i") << QUrl::fromLocalFile(prod->get("resource")).toLocalFile();
         // Output progress info
-        args << QStringLiteral("-progress") << QStringLiteral("/dev/stdout");
-
+        args << QStringLiteral("-progress");
+#ifdef Q_OS_WIN
+        args << QStringLiteral("-");
+#else
+        args << QStringLiteral("/dev/stdout");
+#endif
         bool isFFmpeg = KdenliveSettings::ffmpegpath().contains("ffmpeg");
 
         if (channels == 1) {
@@ -1061,7 +1066,7 @@ void ProjectClip::slotCreateAudioThumbs()
             // Cleanup temporary ffmpeg audio thumb file
             while (!channelFiles.isEmpty()) {
                     delete channelFiles.takeFirst();
-            }            
+            }
             emit updateJobStatus(AbstractClipJob::THUMBJOB, JobDone, 0);
             m_abortAudioThumb = false;
             return;
@@ -1084,7 +1089,7 @@ void ProjectClip::slotCreateAudioThumbs()
                    // Cleanup temporary ffmpeg audio thumb file
                     while (!channelFiles.isEmpty()) {
                         delete channelFiles.takeFirst();
-                    }      
+                    }
                     emit updateJobStatus(AbstractClipJob::THUMBJOB, JobDone, 0);
                     bin()->emitMessage(i18n("Error reading audio thumbnail"), 100, ErrorMessage);
                     return;
@@ -1310,7 +1315,7 @@ const QString ProjectClip::geometryWithOffset(const QString &data, int offset)
 
 QImage ProjectClip::findCachedThumb(int pos)
 {
-    const QString path = url().path() + '_' + QString::number(pos);
+    const QString path = url() + '_' + QString::number(pos);
     return bin()->findCachedPixmap(path);
 }
 
