@@ -26,6 +26,7 @@
 #include <QGraphicsSceneMouseEvent>
 #include <QGraphicsRectItem>
 #include <QGraphicsSvgItem>
+#include <QScrollBar>
 #include <QGraphicsView>
 #include <QCursor>
 #include <QTextCursor>
@@ -97,6 +98,12 @@ void MyTextItem::updateShadow(bool enabled, int blur, int xoffset, int yoffset,
     update();
 }
 
+void MyTextItem::setTextColor(const QColor &col)
+{
+    setDefaultTextColor(col);
+    refreshFormat();
+}
+
 QStringList MyTextItem::shadowInfo() const
 {
     QStringList info;
@@ -124,24 +131,39 @@ void MyTextItem::setAlignment(Qt::Alignment alignment)
     setTextCursor(cursor);
 }
 
+void MyTextItem::refreshFormat()
+{
+    QString gradientData = data(TitleDocument::Gradient).toString();
+    QTextCursor cursor = textCursor();
+    QTextCharFormat cformat;
+    cursor.select(QTextCursor::Document);
+    int position = textCursor().position();
+
+    // Formatting can be lost on paste, since our QTextCursor gets overwritten, so re-apply all formatting here
+    QColor fgColor = defaultTextColor();
+    cformat.setForeground(fgColor);
+    cformat.setFont(font());
+
+    if (!gradientData.isEmpty()) {
+        QRectF rect = boundingRect();
+        QLinearGradient gr = GradientWidget::gradientFromString(gradientData, rect.width(), rect.height());
+        cformat.setForeground(QBrush(gr));
+    }
+
+    //Apply
+    cursor.mergeCharFormat(cformat);
+    // restore cursor position
+    cursor.clearSelection();
+    cursor.setPosition(position);
+    setTextCursor(cursor);
+}
+
 void MyTextItem::updateGeometry(int, int, int)
 {
     updateGeometry();
     // update gradient if necessary
-    QString gradientData = data(TitleDocument::Gradient).toString();
-    if (!gradientData.isEmpty()) {
-        QTextCursor cursor = textCursor(); 
-        QTextCharFormat cformat;
-        QRectF rect = boundingRect();
-        int position = textCursor().position();
-        QLinearGradient gr = GradientWidget::gradientFromString(gradientData, rect.width(), rect.height());
-        cursor.select(QTextCursor::Document);
-        cformat.setForeground(QBrush(gr));
-        cursor.mergeCharFormat(cformat);
-        cursor.clearSelection();
-        cursor.setPosition(position);           // restore cursor position
-        setTextCursor(cursor);
-    }
+    refreshFormat();
+
     QString text = toPlainText();
     m_path = QPainterPath();
     if (text.isEmpty()) {
@@ -466,7 +488,8 @@ GraphicsSceneRectMove::GraphicsSceneRectMove(QObject *parent) :
     m_possibleAction(NoResize),
     m_tool(TITLE_RECTANGLE),
     m_gridSize(20),
-    m_createdText(false)
+    m_createdText(false),
+    m_pan(false)
 {
     //grabMouse();
     m_zoom = 1.0;
@@ -575,8 +598,8 @@ void GraphicsSceneRectMove::mouseDoubleClickEvent(QGraphicsSceneMouseEvent* e)
 
 void GraphicsSceneRectMove::mouseReleaseEvent(QGraphicsSceneMouseEvent *e)
 {
+    m_pan = false;
     if (m_tool == TITLE_RECTANGLE && m_selectedItem) setSelectedItem(m_selectedItem);
-    QGraphicsScene::mouseReleaseEvent(e);
     if (m_createdText) {
         m_selectedItem->setSelected(true);
         MyTextItem *newText = static_cast<MyTextItem*>(m_selectedItem);
@@ -585,11 +608,31 @@ void GraphicsSceneRectMove::mouseReleaseEvent(QGraphicsSceneMouseEvent *e)
         newText->setTextCursor(cur);
         m_createdText = false;
     }
+    if (e->modifiers() & Qt::ShiftModifier) {
+        e->accept();
+    } else {
+        QGraphicsScene::mouseReleaseEvent(e);
+    }
+    QList<QGraphicsView*> viewlist = views();
+    if (!viewlist.isEmpty()) {
+        viewlist.first()->setDragMode(QGraphicsView::RubberBandDrag);
+    }
     emit actionFinished();
 }
 
 void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
 {
+    if (e->buttons() & Qt::MiddleButton) {
+        clearTextSelection();
+        QList<QGraphicsView*> viewlist = views();
+        if (!viewlist.isEmpty()) {
+            viewlist.first()->setDragMode(QGraphicsView::ScrollHandDrag);
+            m_pan = true;
+            e->accept();
+            QGraphicsScene::mousePressEvent(e);
+            return;
+        }
+    }
     int xPos = ((int) e->scenePos().x() / m_gridSize) * m_gridSize;
     int yPos = ((int) e->scenePos().y() / m_gridSize) * m_gridSize;
     m_moveStarted = false;
@@ -597,11 +640,23 @@ void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
     m_resizeMode = m_possibleAction;
     const QList <QGraphicsItem *> list = items(e->scenePos());
     QGraphicsItem *item = NULL;
-    if (e->modifiers() != Qt::ControlModifier) {
-        clearSelection();
-    }
-
     if (m_tool == TITLE_SELECT) {
+        QList<QGraphicsView*> viewlist = views();
+        if (e->modifiers() & Qt::ControlModifier) {
+            clearTextSelection();
+            if (!viewlist.isEmpty()) {
+                viewlist.first()->setDragMode(QGraphicsView::ScrollHandDrag);
+                e->ignore();
+                //QGraphicsScene::mousePressEvent(e);
+                return;
+            }
+        } else {
+            if (!viewlist.isEmpty()) {
+                viewlist.first()->setRubberBandSelectionMode(Qt::IntersectsItemShape);
+            }
+        }
+        QList<QGraphicsItem *> selected = selectedItems();
+        bool alreadySelected = false;
         foreach(QGraphicsItem *g, list) {
             //qDebug() << " - - CHECKING ITEM Z:" << g->zValue() << ", TYPE: " << g->type();
             // check is there is a selected item in list
@@ -609,31 +664,15 @@ void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
                 continue;
             }
             if (g->zValue() > -1000/* && g->isSelected()*/) {
+                alreadySelected = g->isSelected();
                 g->setSelected(true);
                 item = g;
                 break;
             }
         }
-        if (item == NULL  || m_selectedItem != item) {
-            if (m_selectedItem && m_selectedItem->type() == QGraphicsTextItem::Type) {
-                // disable text editing
-                MyTextItem *t = static_cast<MyTextItem *>(m_selectedItem);
-                t->textCursor().setPosition(0);
-                QTextBlock cur = t->textCursor().block();
-                t->setTextCursor(QTextCursor(cur));
-                t->setTextInteractionFlags(Qt::NoTextInteraction);
-            }
-        }
-        if (item == NULL  || !(item->flags() & QGraphicsItem::ItemIsSelectable)) {
-            m_selectedItem = NULL;
-            foreach(QGraphicsItem* g, list) {
-                if (g->zValue() > -1000) {
-                    item = g;
-                    break;
-                }
-            }
-        }
-        if (item != NULL && item->flags() & QGraphicsItem::ItemIsMovable) {
+        if (item == NULL || (e->modifiers() != Qt::ShiftModifier && !alreadySelected)) {
+            clearTextSelection();
+        } else if (item && item->flags() & QGraphicsItem::ItemIsMovable) {
             m_sceneClickPoint = e->scenePos();
             m_selectedItem = item;
             //qDebug() << "/////////  ITEM TYPE: " << item->type();
@@ -682,10 +721,12 @@ void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
         }
         QGraphicsScene::mousePressEvent(e);
     } else if (m_tool == TITLE_RECTANGLE) {
+        clearTextSelection();
         m_sceneClickPoint = QPointF(xPos, yPos);
         m_selectedItem = NULL;
         e->ignore();
     } else if (m_tool == TITLE_TEXT) {
+        clearTextSelection();
         MyTextItem *textItem = new MyTextItem(i18n("Text"), NULL);
         yPos = (((int) e->scenePos().y() - (int)(m_fontSize / 2)) / m_gridSize) * m_gridSize;
         textItem->setPos(xPos, yPos);
@@ -699,7 +740,6 @@ void GraphicsSceneRectMove::mousePressEvent(QGraphicsSceneMouseEvent* e)
         m_createdText = true;
     }
     //qDebug() << "//////  MOUSE CLICK, RESIZE MODE: " << m_resizeMode;
-
 }
 
 void GraphicsSceneRectMove::clearTextSelection()
@@ -718,21 +758,27 @@ void GraphicsSceneRectMove::clearTextSelection()
 
 void GraphicsSceneRectMove::mouseMoveEvent(QGraphicsSceneMouseEvent* e)
 {
+    QList<QGraphicsView*> viewlist = views();
+    if (viewlist.isEmpty()) {
+        e->ignore();
+        return;
+    }
+    QGraphicsView *view = viewlist.first();
+    if (m_pan) {
+        QPoint diff = e->lastScreenPos() - e->screenPos();
+        view->horizontalScrollBar()->setValue(view->horizontalScrollBar()->value() + diff.x());
+        view->verticalScrollBar()->setValue(view->verticalScrollBar()->value() + diff.y());
+        e->accept();
+        QGraphicsScene::mouseMoveEvent(e);
+        return;
+    }
     if (e->buttons() != Qt::NoButton && !m_moveStarted) {
-        QList<QGraphicsView*> viewlist = views();
-        if (viewlist.isEmpty()) {
-            // invalid
-            e->accept();
-            return;
-        }
-        QGraphicsView *view = viewlist.at(0);
         if ((view->mapFromScene(e->scenePos()) - view->mapFromScene(m_clickPoint)).manhattanLength() < QApplication::startDragDistance()) {
             e->ignore();
             QGraphicsScene::mouseMoveEvent(e);
             return;
         } else {
             m_moveStarted = true;
-            e->accept();
         }
     }
     if (m_selectedItem && (e->buttons() & Qt::LeftButton)) {
@@ -794,10 +840,6 @@ void GraphicsSceneRectMove::mouseMoveEvent(QGraphicsSceneMouseEvent* e)
         }
         emit itemMoved();
     } else if (m_tool == TITLE_SELECT) {
-        QList<QGraphicsView*> viewlist = views();
-        QGraphicsView *view = NULL;
-        if (viewlist.size() > 0) view = viewlist[0];
-
         QPointF p = e->scenePos();
         p += QPoint(-2, -2);
         m_resizeMode = NoResize;
