@@ -93,7 +93,7 @@ AnimationWidget::AnimationWidget(EffectMetaInfo *info, int clipPos, int min, int
     connect(m_timePos, SIGNAL(timeCodeEditingFinished()), this, SLOT(slotPositionChanged()));
 
     // seek to previous
-    tb->addAction(KoIconUtils::themedIcon(QStringLiteral("media-skip-backward")), i18n("Previous keyframe"), this, SLOT(slotPrevious()));
+    m_previous = tb->addAction(KoIconUtils::themedIcon(QStringLiteral("media-skip-backward")), i18n("Previous keyframe"), this, SLOT(slotPrevious()));
 
     // Add/remove keyframe
     m_addKeyframe = new KDualAction(i18n("Add keyframe"), i18n("Remove keyframe"), this);
@@ -102,8 +102,8 @@ AnimationWidget::AnimationWidget(EffectMetaInfo *info, int clipPos, int min, int
     connect(m_addKeyframe, SIGNAL(activeChangedByUser(bool)), this, SLOT(slotAddDeleteKeyframe(bool)));
     tb->addAction(m_addKeyframe);
 
-    // seek to previous
-    tb->addAction(KoIconUtils::themedIcon(QStringLiteral("media-skip-forward")), i18n("Next keyframe"), this, SLOT(slotNext()));
+    // seek to next
+    m_next = tb->addAction(KoIconUtils::themedIcon(QStringLiteral("media-skip-forward")), i18n("Next keyframe"), this, SLOT(slotNext()));
 
     // Preset combo
     m_presetCombo = new QComboBox(this);
@@ -262,6 +262,10 @@ void AnimationWidget::updateTimecodeFormat()
 void AnimationWidget::slotPrevious()
 {
     int previous = qMax(-m_offset, m_animController.previous_key(m_timePos->getValue() - m_offset - 1)) + m_offset;
+    if (previous == m_timePos->getValue() && previous > 0) {
+        // Make sure we can seek to effect start even if there is no keyframe
+        previous = 0;
+    }
     m_ruler->setActiveKeyframe(previous);
     slotPositionChanged(previous, true);
 }
@@ -494,6 +498,8 @@ void AnimationWidget::slotPositionChanged(int pos, bool seek)
         updateRect(pos - m_offset);
     }
     updateSlider(pos - m_offset);
+    m_previous->setEnabled(pos > 0);
+    m_next->setEnabled(pos < (m_outPoint - m_inPoint - 1));
     if (seek)
         emit seekToPos(pos);
 }
@@ -618,6 +624,11 @@ void AnimationWidget::updateRect(int pos)
             }
         }
     }
+    double scale = qMin(m_spinWidth->value() / m_monitor->render->frameRenderWidth(), m_spinHeight->value() / m_monitor->render->renderHeight());
+    m_spinSize->blockSignals(true);
+    m_spinSize->setValue(100.0 * scale);
+    m_spinSize->blockSignals(false);
+    m_spinSize->setEnabled(enableEdit);
     m_spinX->setEnabled(enableEdit);
     m_spinY->setEnabled(enableEdit);
     m_spinWidth->setEnabled(enableEdit);
@@ -871,14 +882,19 @@ void AnimationWidget::slotAdjustKeyframeValue(double value)
     m_animController = m_animProperties.get_animation(m_inTimeline.toUtf8().constData());
 
     int pos = m_ruler->position() - m_offset;
+    mlt_keyframe_type type = m_selectType->isEnabled() ? (mlt_keyframe_type) m_selectType->currentAction()->data().toInt() : (mlt_keyframe_type) KdenliveSettings::defaultkeyframeinterp();
     if (m_animController.is_key(pos)) {
         // This is a keyframe
-        m_animProperties.anim_set(m_inTimeline.toUtf8().constData(), value / slider->factor, pos, m_outPoint, (mlt_keyframe_type) m_selectType->currentAction()->data().toInt());
+        type =  m_animController.keyframe_type(pos);
+        m_animProperties.anim_set(m_inTimeline.toUtf8().constData(), value / slider->factor, pos, m_outPoint, type);
 	emit parameterChanged();
     } else if (m_animController.key_count() <= 1) {
 	  pos = m_animController.key_get_frame(0);
 	  if (pos >= 0) {
-	      m_animProperties.anim_set(m_inTimeline.toUtf8().constData(), value / slider->factor, pos, m_outPoint, (mlt_keyframe_type) m_selectType->currentAction()->data().toInt());
+              if (m_animController.is_key(pos)) {
+                  type =  m_animController.keyframe_type(pos);
+              }
+	      m_animProperties.anim_set(m_inTimeline.toUtf8().constData(), value / slider->factor, pos, m_outPoint, type);
 	      emit parameterChanged();
 	  }
     }
@@ -1002,7 +1018,7 @@ void AnimationWidget::slotReverseKeyframeType(bool reverse)
 void AnimationWidget::loadPresets(QString currentText)
 {
     m_presetCombo->blockSignals(true);
-    QDir dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/effects/presets/"));
+    QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/effects/presets/"));
     if (currentText.isEmpty()) currentText = m_presetCombo->currentText();
     while (m_presetCombo->count() > 0) {
         m_presetCombo->removeItem(0);
@@ -1081,7 +1097,7 @@ void AnimationWidget::savePreset()
     if (d.exec() != QDialog::Accepted) {
         return;
     }
-    QDir dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/effects/presets/"));
+    QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/effects/presets/"));
     if (!dir.exists()) {
         dir.mkpath(QStringLiteral("."));
     }
@@ -1104,7 +1120,7 @@ void AnimationWidget::deletePreset()
 {
     QString effectName = m_presetCombo->currentText();
     // try deleting as effect preset first
-    QDir dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/effects/presets/"));
+    QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QStringLiteral("/effects/presets/"));
     KConfig confFile(dir.absoluteFilePath(m_effectId), KConfig::SimpleConfig);
     KConfigGroup grp(&confFile, effectName);
     if (grp.exists()) {
