@@ -49,9 +49,14 @@ int main(int argc, char *argv[])
     QCoreApplication::setAttribute(Qt::AA_X11InitThreads);
 #endif
 
+#ifdef Q_OS_WIN
+    qputenv("KDE_FORK_SLAVES", "1");
+#endif
+
     // Init application
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kdenlive"));
+    app.setOrganizationDomain("kde.org");
     app.setWindowIcon(QIcon(":/pics/kdenlive.png"));
     KLocalizedString::setApplicationDomain("kdenlive");
     KSharedConfigPtr config = KSharedConfig::openConfig();
@@ -68,10 +73,14 @@ int main(int argc, char *argv[])
         }
     }
 
+    // Init DBus services
+    KDBusService programDBusService;
+
     bool forceBreeze = grp.readEntry("force_breeze", QVariant(false)).toBool();
     if (forceBreeze) {
         QIcon::setThemeName("breeze");
     }
+
     // Create KAboutData
     KAboutData aboutData(QByteArray("kdenlive"),
                          i18n("Kdenlive"), KDENLIVE_VERSION,
@@ -100,11 +109,9 @@ int main(int argc, char *argv[])
     // Register about data
     KAboutData::setApplicationData(aboutData);
 
-#ifndef __MINGW32__
     // Add rcc stored icons to the search path so that we always find our icons
     KIconLoader *loader = KIconLoader::global();
     loader->reconfigure("kdenlive", QStringList() << QStringLiteral(":/pics"));
-#endif
 
     // Set app stuff from about data
     app.setApplicationDisplayName(aboutData.displayName());
@@ -126,7 +133,6 @@ int main(int argc, char *argv[])
     // Parse command line
     parser.process(app);
     aboutData.processCommandLine(&parser);
-    KDBusService programDBusService;
 
 #if KXMLGUI_VERSION_MINOR > 14 || KXMLGUI_VERSION_MAJOR > 5
     KCrash::initialize();
