@@ -109,6 +109,7 @@ GLWidget::GLWidget(int id, QObject *parent)
         mlt_properties_set_data(mlt_global_properties(), "glslManager", NULL, 0, NULL, NULL);
         emit gpuNotSupported();
     }
+    connect(this, SIGNAL(sceneGraphInitialized()), SLOT(createOffscreen()));
     connect(this, SIGNAL(sceneGraphInitialized()), SLOT(initializeGL()), Qt::DirectConnection);
     connect(this, SIGNAL(beforeRendering()), SLOT(paintGL()), Qt::DirectConnection);
 }
@@ -142,14 +143,17 @@ void GLWidget::updateAudioForAnalysis()
 	m_frameRenderer->sendAudioForAnalysis = KdenliveSettings::monitor_audio();
 }
 
-void GLWidget::initializeGL()
+void GLWidget::createOffscreen()
 {
-    if (m_isInitialized || !isVisible() || !openglContext()) return;
     if (!m_offscreenSurface.isValid()) {
         m_offscreenSurface.setFormat(openglContext()->format());
         m_offscreenSurface.create();
-        openglContext()->makeCurrent(this);
     }
+}
+
+void GLWidget::initializeGL()
+{
+    if (m_isInitialized || !isVisible() || !openglContext()) return;
     initializeOpenGLFunctions();
     qDebug() << "OpenGL vendor: " << QString::fromUtf8((const char*) glGetString(GL_VENDOR));
     qDebug() << "OpenGL renderer: " << QString::fromUtf8((const char*) glGetString(GL_RENDERER));
@@ -572,37 +576,54 @@ void GLWidget::wheelEvent(QWheelEvent * event)
 
 void GLWidget::mousePressEvent(QMouseEvent* event)
 {
-    QQuickView::mousePressEvent(event);
-    if (event->isAccepted()) return;
-    if (rootObject() && rootObject()->objectName() != QLatin1String("root")) {
+    if (rootObject() && rootObject()->objectName() != QLatin1String("root") && !(event->modifiers() & Qt::ControlModifier) && !(event->buttons() & Qt::MiddleButton)) {
         event->ignore();
+        QQuickView::mousePressEvent(event);
         return;
     }
     if (event->button() & Qt::LeftButton) {
-        m_dragStart = event->pos();
+        if (event->modifiers() & Qt::ControlModifier) {
+            // Pan view
+            m_panStart = event->pos();
+            setCursor(Qt::ClosedHandCursor);
+        } else {
+            m_dragStart = event->pos();
+        }
     }
     else if (event->button() & Qt::RightButton) {
         emit showContextMenu(event->globalPos());
-        event->accept();
+    } else if (event->button() & Qt::MiddleButton) {
+        m_panStart = event->pos();
+        setCursor(Qt::ClosedHandCursor);
     }
+    event->accept();
+    QQuickView::mousePressEvent(event);
 }
 
 void GLWidget::mouseMoveEvent(QMouseEvent* event)
 {
-    QQuickView::mouseMoveEvent(event);
-    if (event->isAccepted()) return;
-    if (rootObject() && rootObject()->objectName() != QLatin1String("root")) {
+    if (rootObject() && rootObject()->objectName() != QLatin1String("root") && !(event->modifiers() & Qt::ControlModifier) && !(event->buttons() & Qt::MiddleButton)) {
         event->ignore();
+        QQuickView::mouseMoveEvent(event);
         return;
     }
-    if (event->isAccepted()) return;
-/*    if (event->modifiers() == Qt::ShiftModifier && m_producer) {
+    /*    if (event->modifiers() == Qt::ShiftModifier && m_producer) {
         emit seekTo(m_producer->get_length() *  event->x() / width());
         return;
     }*/
-    if (!(event->buttons() & Qt::LeftButton))
+    QQuickView::mouseMoveEvent(event);
+    if (!m_panStart.isNull()) {
+        emit panView(m_panStart - event->pos());
+        m_panStart = event->pos();
+        event->accept();
+        QQuickView::mouseMoveEvent(event);
         return;
-    if (!m_dragStart.isNull() &&  (event->pos() - m_dragStart).manhattanLength() >= QApplication::startDragDistance()) {
+    }
+    if (!(event->buttons() & Qt::LeftButton)) {
+        QQuickView::mouseMoveEvent(event);
+        return;
+    }
+    if (!event->isAccepted() && !m_dragStart.isNull() &&  (event->pos() - m_dragStart).manhattanLength() >= QApplication::startDragDistance()) {
         m_dragStart = QPoint();
         emit startDrag();
     }
@@ -1119,17 +1140,16 @@ void GLWidget::onFrameDisplayed(const SharedFrame &frame)
 void GLWidget::mouseReleaseEvent(QMouseEvent * event)
 {
     QQuickView::mouseReleaseEvent(event);
-    if (m_dragStart.isNull() || event->isAccepted()) {
-        // we are dragging
+    if (m_dragStart.isNull() && m_panStart.isNull() && rootObject() && rootObject()->objectName() != QLatin1String("root") && !(event->modifiers() & Qt::ControlModifier)) {
+        event->ignore();
         return;
     }
-    if (rootObject() && rootObject()->objectName() != QLatin1String("root")) {
-        return;
-    }
-    m_dragStart = QPoint();
-    if (event->button() != Qt::RightButton) {
+    if (!m_dragStart.isNull() && m_panStart.isNull() && event->button() & Qt::LeftButton && !event->isAccepted()) {
         emit monitorPlay();
     }
+    m_dragStart = QPoint();
+    m_panStart = QPoint();
+    setCursor(Qt::ArrowCursor);
 }
 
 void GLWidget::mouseDoubleClickEvent(QMouseEvent * event)
