@@ -161,6 +161,7 @@ Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *paren
     // Create QML OpenGL widget
     m_glMonitor = new GLWidget((int) id);
     connect(m_glMonitor, SIGNAL(passKeyEvent(QKeyEvent*)), this, SLOT(doKeyPressEvent(QKeyEvent*)));
+    connect(m_glMonitor, &GLWidget::panView, this, &Monitor::panView);
     m_videoWidget = QWidget::createWindowContainer(qobject_cast<QWindow*>(m_glMonitor));
     m_videoWidget->setAcceptDrops(true);
     QuickEventEater *leventEater = new QuickEventEater(this);
@@ -499,6 +500,7 @@ void Monitor::setupMenu(QMenu *goMenu, QMenu *overlayMenu, QAction *playZone, QA
     switchAudioMonitor->setChecked(KdenliveSettings::monitoraudio() & m_id);
     m_configMenu->addAction(overlayAudio);
     m_configMenu->addAction(m_zoomVisibilityAction);
+    m_contextMenu->addAction(m_zoomVisibilityAction);
     // For some reason, the frame in QAbstracSpinBox (base class of TimeCodeDisplay) needs to be displayed once, then hidden
     // or it will never appear (supposed to appear on hover).
     m_timePos->setFrame(false);
@@ -1015,7 +1017,7 @@ void Monitor::slotExtractCurrentFrame(QString path, bool addToProject)
                 frame = render->extractFrame(render->seekFramePosition());
             }
             frame.save(savePath.toLocalFile());
-            KRecentDirs::add(QStringLiteral(":KdenliveFramesFolder"), savePath.adjusted(QUrl::RemoveFilename).path());
+            KRecentDirs::add(QStringLiteral(":KdenliveFramesFolder"), savePath.adjusted(QUrl::RemoveFilename).toLocalFile());
 
             if (addToProject) {
                 QStringList folderInfo = pCore->bin()->getFolderInfo();
@@ -1749,12 +1751,14 @@ void Monitor::slotSwitchCompare(bool enable, int pos)
                 // Split scene is already active
                 return;
             }
-            m_splitEffect = new Mlt::Filter(*profile(), "frei0r.scale0tilt");
+            m_splitEffect = new Mlt::Filter(*profile(), "frei0r.alphagrad");
             if (m_splitEffect && m_splitEffect->is_valid()) {
                 m_splitEffect->set("0", 0.5); // 0 is the Clip left parameter
+                m_splitEffect->set("1", 0); // 1 is gradient width
+                m_splitEffect->set("2", -0.747); // 2 is tilt
             } else {
                 // frei0r.scal0tilt is not available
-                warningMessage(i18n("The scal0tilt filter is required for that feature, please install frei0r and restart Kdenlive"));
+                warningMessage(i18n("The alphagrad filter is required for that feature, please install frei0r and restart Kdenlive"));
                 return;
             }
             emit createSplitOverlay(m_splitEffect);
@@ -1798,12 +1802,14 @@ void Monitor::slotSwitchCompare(bool enable, int pos)
 
 void Monitor::buildSplitEffect(Mlt::Producer *original, int pos)
 {
-    m_splitEffect = new Mlt::Filter(*profile(), "frei0r.scale0tilt");
+    m_splitEffect = new Mlt::Filter(*profile(), "frei0r.alphagrad");
     if (m_splitEffect && m_splitEffect->is_valid()) {
         m_splitEffect->set("0", 0.5); // 0 is the Clip left parameter
+        m_splitEffect->set("1", 0); // 1 is gradient width
+        m_splitEffect->set("2", -0.747); // 2 is tilt        
     } else {
         // frei0r.scal0tilt is not available
-        warningMessage(i18n("The scal0tilt filter is required for that feature, please install frei0r and restart Kdenlive"));
+        warningMessage(i18n("The alphagrad filter is required for that feature, please install frei0r and restart Kdenlive"));
         return;
     }
     QString splitTransition = TransitionHandler::compositeTransition();
@@ -1940,7 +1946,7 @@ void Monitor::slotAdjustEffectCompare()
     if (m_qmlManager->sceneType() == MonitorSceneSplit) {
         // Adjust splitter pos
         QQuickItem *root = m_glMonitor->rootObject();
-        percent = (root->property("splitterPos").toInt() - r.left()) / (double) r.width();
+        percent = 0.5 - ((root->property("splitterPos").toInt() - r.left() - r.width() / 2.0) / (double) r.width() / 2.0) / 0.75;
         // Store real frame percentage for resize events
         root->setProperty("realpercent", percent);
     }
@@ -2084,3 +2090,16 @@ void Monitor::clearDisplay()
 {
     m_glMonitor->clear();
 }
+
+void Monitor::panView(QPoint diff)
+{
+    // Only pan if scrollbars are visible
+    if (m_horizontalScroll->isVisible()) {
+        m_horizontalScroll->setValue(m_horizontalScroll->value() + diff.x());
+    }
+    if (m_verticalScroll->isVisible()) {
+        m_verticalScroll->setValue(m_verticalScroll->value() + diff.y());
+    }
+}
+
+
