@@ -302,7 +302,7 @@ StopmotionWidget::StopmotionWidget(MonitorManager *manager, const QUrl &projectF
     // Create MLT producer data
     if (capture_device->itemData(capture_device->currentIndex()) == "v4l") {
         // Capture using a video4linux device
-        profilePath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/profiles/video4linux";
+        profilePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/profiles/video4linux";
     }
     else {
         // Decklink capture
@@ -432,7 +432,7 @@ void StopmotionWidget::parseExistingSequences()
 {
     sequence_name->clear();
     sequence_name->addItem(QString());
-    QDir dir(m_projectFolder.path());
+    QDir dir(m_projectFolder.toLocalFile());
     QStringList filters;
     filters << QStringLiteral("*_0000.png");
     //dir.setNameFilters(filters);
@@ -469,7 +469,7 @@ void StopmotionWidget::slotLive(bool isOn)
         // Create MLT producer data
         if (capture_device->itemData(capture_device->currentIndex()) == "v4l") {
             // Capture using a video4linux device
-            profilePath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + "/profiles/video4linux";
+            profilePath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + "/profiles/video4linux";
             profile = ProfilesDialog::getVideoProfile(profilePath);
             service = QStringLiteral("avformat-novalidate");
             QString devicePath = capture_device->itemData(capture_device->currentIndex(), Qt::UserRole + 1).toString();
@@ -715,7 +715,7 @@ QString StopmotionWidget::getPathForFrame(int ix, QString seqName)
 {
     if (seqName.isEmpty())
         seqName = m_sequenceName;
-    return m_projectFolder.path() + QDir::separator() + seqName + QLatin1Char('_') + QString::number(ix).rightJustified(4, '0', false) + QStringLiteral(".png");
+    return m_projectFolder.toLocalFile() + QDir::separator() + seqName + QLatin1Char('_') + QString::number(ix).rightJustified(4, '0', false) + QStringLiteral(".png");
 }
 
 void StopmotionWidget::slotShowFrame(const QString& path)
