@@ -532,7 +532,7 @@ void Timeline::parseDocument(const QDomDocument &doc)
     if (!m_documentErrors.isNull()) KMessageBox::sorry(this, m_documentErrors);
     if (mlt.hasAttribute(QStringLiteral("upgraded")) || mlt.hasAttribute(QStringLiteral("modified"))) {
         // Our document was upgraded, create a backup copy just in case
-        QString baseFile = m_doc->url().path().section(QStringLiteral(".kdenlive"), 0, 0);
+        QString baseFile = m_doc->url().toLocalFile().section(QStringLiteral(".kdenlive"), 0, 0);
         int ct = 0;
         QString backupFile = baseFile + "_backup" + QString::number(ct) + ".kdenlive";
         while (QFile::exists(backupFile)) {
@@ -1310,9 +1310,10 @@ void Timeline::checkTrackHeight(bool force)
     if (m_trackview->checkTrackHeight(force)) {
         m_doc->clipManager()->clearCache();
         m_ruler->updateFrameSize();
-        m_trackview->updateSceneFrameWidth();
         slotChangeZoom(m_doc->zoom().x(), m_doc->zoom().y());
         slotSetZone(m_doc->zone(), false);
+        m_ruler->setPixelPerMark(m_doc->zoom().x(), true);
+        m_trackview->updateSceneFrameWidth();
     }
 }
 
@@ -1870,7 +1871,7 @@ void Timeline::loadPreviewRender()
     m_disablePreview->blockSignals(true);
     m_disablePreview->setChecked(m_doc->getDocumentProperty(QStringLiteral("disablepreview")).toInt());
     m_disablePreview->blockSignals(false);
-    QDateTime documentDate = QFileInfo(m_doc->url().path()).lastModified();
+    QDateTime documentDate = QFileInfo(m_doc->url().toLocalFile()).lastModified();
     if (!chunks.isEmpty() || !dirty.isEmpty()) {
         if (!m_timelinePreview) {
             initializePreview();
