@@ -387,7 +387,10 @@ QList <ItemInfo> Track::replaceAll(const QString &id, Mlt::Producer *original, M
                 // No duplication required
                 cut = original->cut(p->get_in(), p->get_out());
             }
-            else {
+            else if (!idForTrack.contains(QStringLiteral("_")) && idForTrack == current.section(QStringLiteral("_"), 0, 0)) {
+                // Unproxying a slideshow
+                cut = original->cut(p->get_in(), p->get_out());
+            } else {
 		continue;
 	    }
         }
@@ -395,11 +398,13 @@ QList <ItemInfo> Track::replaceAll(const QString &id, Mlt::Producer *original, M
 	        // No audio - no duplication required
                 cut = original->cut(p->get_in(), p->get_out());
 	}
-        else if (!cut && current == idForTrack) {
+        else if (!cut && ((current == idForTrack) || (!current.contains(QStringLiteral("_")) && current == idForTrack.section(QStringLiteral("_"), 0, 0)))) {
             // Use duplicate
             if (trackProducer == NULL) {
-                trackProducer = Clip(*original).clone();
-                trackProducer->set("id", idForTrack.toUtf8().constData());
+                if (idForTrack.contains(QStringLiteral("_"))) {
+                    trackProducer = Clip(*original).clone();
+                    trackProducer->set("id", idForTrack.toUtf8().constData());
+                }
             }
             cut = trackProducer->cut(p->get_in(), p->get_out());
         }
